% *** Received power for various scenarios ***
% file: RadEqu_1.m
% update: August 5th, 2014
 
% Some experiments along with the Radar Equation,
% reference:  Pozar, [1], p. 662

clc;
clear;
c0 = 2.998e8;		% speed of light 

%% activate one of the following scenarios ...
%% ... in order to perform appropriate power ...
%% ... calculations :
%scenario='MilitaryPlane';          % -67 dBm
scenario='SUV_with_amp';         % -40 dBm
%scenario='SUV_no_amp';            % -78 dBm
%scenario='Lab_Cond_with_amp';      % -23 dBm
%scenario='Lab_Cond_no_amp';         % -54 dBm
%scenario='Pozar'                    % -90 dBm

disp(scenario);

switch(scenario)
	
case{'MilitaryPlane'}
		
	pow_BBA150 = 56;		% 1 dB compression point power 400 W = 56 dBm
	gain_HF907= 9;			% gain of R&S antenna type HF907 at 2.4 GHz

	Pt=pow_BBA150;    		% power in dBm
	Ptw = 10^(Pt/10);

	G=gain_HF907;    		% gain of transmit antenna in dBi
	Gl=10^(G/10);  		    % linear gain

	f=2.4e9;				% frequency in  Hz
	la=c0/f;				% wavelength in m

	sigma=60;			    % Transall military transport plane in m^2

	R=500;					% distance in m

	Pr=Ptw*Gl^2*la^2*sigma/((4*pi)^3*R^4);    % received power in Watts

	Prlog=10*log10(Pr)		% received power in dBm	

	
case{'SUV_with_amp'}
		
	pow_BBA150 = 56;		% 1 dB compression point power 400 W = 56 dBm
	gain_HF907= 9;			% gain of R&S antenna type HF907 at 2.4 GHz

	Pt=pow_BBA150;    		% power in dBm
	Ptw = 10^(Pt/10);

	G=gain_HF907;    		% gain of transmit antenna in dBi
	Gl=10^(G/10);  		    % linear gain

	f=2.4e9;				% frequency in  Hz
	la=c0/f;				% wavelength in m

	sigma=3;			   % SUV car radar cross section in m^2

	R=50;					% distance in m

	Pr=Ptw*Gl^2*la^2*sigma/((4*pi)^3*R^4);    % received power in Watts

	Prlog=10*log10(Pr)		% received power in dBm	

end    % end switch
